@@ -45,6 +45,12 @@
 #define SPICE_TICKET_KEY_PAIR_LENGTH 1024
 #define SPICE_TICKET_PUBKEY_BYTES (SPICE_TICKET_KEY_PAIR_LENGTH / 8 + 34)
 
+/*
+ * This is the maximum number of streams possible.
+ * IDs will be in the interval [0, SPICE_MAX_NUM_STREAMS).
+ */
+#define SPICE_MAX_NUM_STREAMS 64
+
 typedef struct SPICE_ATTR_PACKED SpiceLinkHeader {
     uint32_t magic;
     uint32_t major_version;
@@ -136,12 +142,23 @@ enum {
     SPICE_DISPLAY_CAP_STREAM_REPORT,
     SPICE_DISPLAY_CAP_LZ4_COMPRESSION,
     SPICE_DISPLAY_CAP_PREF_COMPRESSION,
+    SPICE_DISPLAY_CAP_GL_SCANOUT,
+    SPICE_DISPLAY_CAP_MULTI_CODEC,
+    SPICE_DISPLAY_CAP_CODEC_MJPEG,
+    SPICE_DISPLAY_CAP_CODEC_VP8,
+    SPICE_DISPLAY_CAP_CODEC_H264,
+    SPICE_DISPLAY_CAP_PREF_VIDEO_CODEC_TYPE,
+    SPICE_DISPLAY_CAP_CODEC_VP9,
 };
 
 enum {
     SPICE_INPUTS_CAP_KEY_SCANCODE,
 };
 
+enum {
+    SPICE_SPICEVMC_CAP_DATA_COMPRESS_LZ4,
+};
+
 enum {
     SPICE_PORT_EVENT_OPENED,
     SPICE_PORT_EVENT_CLOSED,
